
class StreamQueue(object):

    def __init__(self, stream, sets):
        self.stream = stream
        self.sets = sets

    @staticmethod
    def parse(data):
        return StreamQueue(

        )

    def get_stream(self):
        return self.stream

    def get_sets(self):
        return self.sets